#
# spec file for package kubectl-directpv
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define __arch_install_post export NO_BRP_STRIP_DEBUG=true

Name:           kubectl-directpv
Version:        4.1.4
Release:        1.3
Summary:        Kubectl plugin for the MinIO CSI driver for Direct Attached Storage
License:        Apache-2.0
URL:            https://github.com/minio/directpv
Source:         %{name}-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  go1.22

%description
DirectPV is a CSI driver for Direct Attached Storage. In a simpler sense, it is
a distributed persistent volume manager, and not a storage system like SAN or
NAS. It is useful to discover, format, mount, schedule and monitor drives
across servers.

This package contains the Kubectl plugin to manage the DirectPV CSI driver.

%prep
%autosetup -a 1 -p 1

%build
go build \
   -mod=vendor \
   -buildmode=pie \
   -tags "osusergo netgo" \
   -ldflags="-X main.Version=v%{version}" \
   -o bin/%{name} ./cmd/kubectl-directpv

%install
# Install the binary.
install -D -m 0755 bin/%{name} "%{buildroot}/%{_bindir}/%{name}"

%check

%files
%doc README.md
%license LICENSE
%{_bindir}/%{name}

%changelog
* Fri Sep 20 2024 opensuse_buildservice@ojkastl.de
- Update to version 4.1.4:
  * Add `target_commitish` to goreleaser spec (#950)
* Sat Sep 14 2024 opensuse_buildservice@ojkastl.de
- Update to version 4.1.3:
  * Upgrade sidecars to latest (#946)
  * fix: do not allow removing/changing the reserved labels (#944)
  * Add csi-external-health-monitor-controller sidecar build (#940)
  * Add info messages in sidecar release scripts (#939)
  * install: initialize admin and legacy client to avoid crash for
    dry-run mode (#937)
  * admin: add missing response fields in resume APIs (#936)
  * Add sidecar release scripts (#934)
  * admin: return additional info in admin API responses (#935)
* Sat Sep 14 2024 opensuse_buildservice@ojkastl.de
- Update to version 4.1.2:
  * Fix size probe for invalid devices (#931)
  * docs: fix piped sh usage (#929)
  * fix regression assigning AuditWriter in installer args (#926)
  * Upgrade sidecar images (#920)
  * Remove unsupported PodSecurityPolicy (#918)
  * Add drive repair support (#880)
  * upgrade dependencies (#917)
  * Export DirectPV client and admin API package (#889)
  * upgrade dependencies (#914)
  * Upgrade UBI 8.10 and dependencies (#911)
* Sat Sep 14 2024 opensuse_buildservice@ojkastl.de
- Update to version 4.1.1:
  * docs: fix piped sh usage (#929)
  * fix regression assigning AuditWriter in installer args (#926)
* Tue Aug 13 2024 opensuse_buildservice@ojkastl.de
- Update to version 4.1.0:
  * Upgrade sidecar images (#920)
  * Remove unsupported PodSecurityPolicy (#918)
* Tue Aug 13 2024 opensuse_buildservice@ojkastl.de
- Update to version 4.0.13:
  * Upgrade sidecar images (#922)
* Thu Aug  1 2024 opensuse_buildservice@ojkastl.de
- Update to version 4.0.12:
  * Add drive repair support (#880)
  * upgrade dependencies (#917)
  * Export DirectPV client and admin API package (#889)
* Mon Jun 24 2024 opensuse_buildservice@ojkastl.de
- Update to version 4.0.11:
  * upgrade dependencies (#914)
  * Upgrade UBI 8.10 and dependencies (#911)
  * fix: handle Add event in node event listener (#906)
  * Bump golang.org/x/net from 0.22.0 to 0.23.0 (#905)
  * Update dependencies (#899)
  * fix link to create-storage-class.sh (#896)
  * update max_retries in XFS error condition config to 0 (#893)
  * Update operator bundle for v4.0.10
  * Update Helm charts for v4.0.10
* Thu Apr 18 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- do not strip aka remove -s -w ldflags
* Wed Apr  3 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- new package kubectl-directpv: Kubectl plugin for the MinIO CSI
  driver for Direct Attached Storage
